/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2014, Arnaud Roques
 *
 * Project Info:  http://plantuml.sourceforge.net
 * 
 * This file is part of PlantUML.
 *
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS ECLIPSE PUBLIC
 * LICENSE ("AGREEMENT"). [Eclipse Public License - v 1.0]
 * 
 * ANY USE, REPRODUCTION OR DISTRIBUTION OF THE PROGRAM CONSTITUTES
 * RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.
 * 
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *
 * Original Author:  Arnaud Roques
 */
package net.sourceforge.plantuml.project;

class FormalAdditionInstantDuration implements Formal {

	private final Expression exp1;
	private final Expression exp2;
	private final InstantArithmetic math;

	public FormalAdditionInstantDuration(Expression exp1, Expression exp2, InstantArithmetic math) {
		this.exp1 = exp1;
		this.exp2 = exp2;
		this.math = math;
	}

	public String getDescription() {
		return "addID " + exp1 + " " + exp2;
	}

	public NumericType getNumericType() {
		return exp1.getNumericType();
	}

	public Numeric getValue() {
		if (exp2.getNumericType() == NumericType.NUMBER) {
			final Duration d = new Duration((NumericNumber) exp2.getValue());
			return math.add((Instant) exp1.getValue(), d);
		}

		return math.add((Instant) exp1.getValue(), (Duration) exp2.getValue());
	}

}
